From 1cc181b3e0fd026b5782e671bd0cc3e5755d870f Mon Sep 17 00:00:00 2001
From: Rob Browning <rlb@defaultvalue.org>
Date: Sun, 9 Dec 2012 12:16:11 -0600
Subject: [PATCH 2/2] Invoke each add-on install script correctly as new-style
 or old-style.
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit

Previously, emacs-package-install would invoke all of the add-on
install scripts in a dependency chain as either old-style or
new-style, based solely on whether or not the package that triggered
the install was old-style or new-style.

Now it should invoke each package's install script based on whether or
not the package itself is new-style or old-style, as determined by the
presence or absence of the policy-required
/usr/lib/emacsen-common/packages/compat/PACAKGE file.

Thanks to Sébastien Villemot <sebastien@debian.org> for the report.
(closes: #693472)
---
 emacs-package-install |   19 +++++++++++--------
 1 file changed, 11 insertions(+), 8 deletions(-)

diff --git a/emacs-package-install b/emacs-package-install
index f97b1db..1efdb05 100755
--- a/emacs-package-install
+++ b/emacs-package-install
@@ -26,6 +26,12 @@ sub usage
   }
 }
 
+sub is_new_pkg
+{
+  my($pkg) = @_;
+  return (-e  "$lib_dir/packages/compat/$pkg");
+}
+
 if(scalar(@ARGV) == 1)
 {
   $invoked_by_old_pkg = 1;
@@ -64,11 +70,12 @@ if($context eq 'preinst')
 my @pkgs_to_handle = generate_add_on_install_list([$pkg]);
 my @installed_flavors = get_installed_flavors();
 
-if(!$invoked_by_old_pkg)
+foreach my $pkg (@pkgs_to_handle)
 {
-  foreach my $pkg (@pkgs_to_handle)
+  my $script = $lib_dir . "/packages/install/$pkg";
+
+  if(is_new_pkg($pkg))
   {
-    my $script = $lib_dir . "/packages/install/$pkg";
     foreach my $flavor (@installed_flavors)
     {
       print "Install $pkg for $flavor\n";
@@ -79,12 +86,8 @@ if(!$invoked_by_old_pkg)
       }
     }
   }
-}
-else # $invoked_by_old_pkg
-{
-  foreach my $pkg (@pkgs_to_handle)
+  else # old pkg
   {
-    my $script = $lib_dir . "/packages/install/$pkg";
     print "Install $pkg for emacs\n";
     ex($script, 'emacs', @installed_flavors) if -e $script;
 
-- 
1.7.10.4

